diff src/msdos.c @ 99540:c5c8f07bc47c

* w32-fns.el (w32-shell-dos-semantics): * calendar/diary-lib.el (diary-face-attrs): * international/mule-cmds.el (set-default-coding-systems) (prefer-coding-system): * net/tramp.el (tramp-set-completion-function): * progmodes/vhdl-mode.el (vhdl-file-header): * term/pc-win.el (msdos-show-help): Fix typos in docstrings. * emacs-lisp/authors.el (authors-fixed-entries): Fix typo in value. * files.el (enable-local-eval, not-modified, kill-buffer-ask) (kill-matching-buffers, save-buffers-kill-emacs) (save-buffers-kill-terminal): Fix typos in docstrings. (switch-to-buffer-other-window): Reflow docstring. (revert-buffer): Doc fix. (define-project-bindings): Rename arg LIST to SETTINGS. (project-find-settings-file): Use `let', not `let*'. Use `when'.
author Juanma Barranquero <lekktu@gmail.com>
date Fri, 14 Nov 2008 13:05:18 +0000
parents 5c5323a73e60
children e84316087c93
line wrap: on
line diff
--- a/src/msdos.c	Fri Nov 14 12:17:38 2008 +0000
+++ b/src/msdos.c	Fri Nov 14 13:05:18 2008 +0000
@@ -4280,7 +4280,7 @@
 
 DEFUN ("msdos-long-file-names", Fmsdos_long_file_names, Smsdos_long_file_names,
        0, 0, 0,
-       doc: /* Return non-nil if long file names are supported on MSDOS.  */)
+       doc: /* Return non-nil if long file names are supported on MS-DOS.  */)
      ()
 {
   return (_USE_LFN ? Qt : Qnil);
@@ -5247,7 +5247,7 @@
 
   DEFVAR_LISP ("dos-unsupported-char-glyph", &Vdos_unsupported_char_glyph,
 	       doc: /* *Glyph to display instead of chars not supported by current codepage.
-This variable is used only by MSDOS terminals.  */);
+This variable is used only by MS-DOS terminals.  */);
   Vdos_unsupported_char_glyph = make_number ('\177');
 
 #endif